# Menagerie

A static site generator that supports:

- Markdown
- HTML
- JSON Schemas (Limited)
- XML Schemas
- YAML Schemas (Coming soon)

# Documentation

Documentation for how to use menagerie is located at [https://bwc9876.github.io/menagerie/](https://bwc9876.github.io/menagerie/)


# Contributing 

To contribute to menagerie, take a look at [CONTRIBUTING.md](https://github.com/Bwc9876/menagerie/CONTRIBUTING.md)
